/* This file is part of the KDE project
   Copyright (C) 2002-2003 Nadeem Hasan <nhasan@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or ( at your option ) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License

   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef CALLERID_H
#define CALLERID_H

#include <qobject.h>
#include <qstring.h>
#include <qregexp.h>

#include "calllog.h"

class Modem;
class KallersConfig;

class CallerId : public QObject
{
  Q_OBJECT

  public:
    CallerId( QObject *parent=0, const char *name=0 );
    ~CallerId();

    void clearCallLog();

    CallLog *callLog() { return m_callLog; }
    uint numCalls() { return m_callLog->count(); }
    uint newCalls() { return m_callLog->newCount(); }
    bool offline() { return m_offline; }

  protected slots:

    void slotGotLine( const char * );
    void slotOffline();
    void initModem();

  signals:

    void callReceived( const CallData * );
    void offlineChanged( bool );

  protected:

    void openModem();
    void closeModem();
    void initRegExp();
    void addLogEntry( CallData * );
    void checkAnonymous();
    void setOffline( bool );

    QRegExp m_reName;
    QRegExp m_reNmbr;
    QRegExp m_reDate;
    QRegExp m_reTime;
    QRegExp m_reMesg;

    bool m_offline;
    QString m_ringFile;
    Modem *m_modem;
    CallData *m_curCallData;
    CallLog *m_callLog;
    KallersConfig *m_config;
};

#endif // CALLERID_H

/* vim: et sw=2 ts=2
*/

