/* This file is part of the KDE project
   Copyright (C) 2002-2003 Nadeem Hasan <nhasan@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or ( at your option ) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef CALLLOG_H
#define CALLLOG_H

#include <qstring.h>
#include <qdatetime.h>
#include <qptrlist.h>

class QDomDocument;

class CallData
{
  public:

    CallData();

    QString name() const { return m_callerName; }
    QString nmbr() const { return m_callerNumber; }
    QString mesg() const { return m_mesg; }
    QDateTime time() const { return m_callTime; }
    bool isAnonymous() const { return m_anonCall; }
    bool isNew() const { return m_newCall; }

    void setName( const QString &s ) { m_callerName = s; }
    void setNmbr( const QString &s ) { m_callerNumber = s; }
    void setMesg( const QString &s ) { m_mesg = s; }
    void setTime( int, int );
    void setDate( int, int );
    void setDateTime( const QString & );
    void setAnonymous( bool b ) { m_anonCall = b; }
    void setNew( bool b ) { m_newCall = b; }

  protected:

    QString m_callerName;
    QString m_callerNumber;
    QString m_mesg;
    QDateTime m_callTime;
    bool m_anonCall, m_newCall;
};

class CallLog : public QPtrList<CallData>
{
  public:

    CallLog();
    ~CallLog();

    bool atFirst() { return current() == getFirst(); }
    bool atLast() { return current() == getLast(); }
    void add( CallData * );

    uint newCount()
    {
      uint count = 0;
      CallData *data = first();
      while (  data )
      {
        if (  data->isNew() ) ++count;
        data = next();
      }
      return count;
    }

  private:

    void parse();
    void save();
    QDomDocument createDom();

    QString m_fileName;
};

#endif // CALLLOG_H

/* vim: et sw=2 ts=2
*/
