/* This file is part of the KDE project
   Copyright (C) 2002-2003 Nadeem Hasan <nhasan@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or ( at your option ) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <klocale.h>
#include <kcombobox.h>
#include <knuminput.h>

#include <qcheckbox.h>
#include <qvbox.h>

#include "kallersconfig.h"
#include "configwidget.h"
#include "kallersconfdialog.h"

KallersConfDialog::KallersConfDialog( QWidget *parent, const char *name )
        : KDialogBase( parent, name, true, i18n( "Kallers Configuration" ),
          Ok|Apply|Cancel, Ok, true ),
          m_config( 0 ), m_confWidget( 0 )
{
  m_config = KallersConfig::instance();

  QVBox *vbox = makeVBoxMainWidget();

  m_confWidget = new ConfigWidget( vbox, "m_confWidget" );

  m_confWidget->comboDevice->setCurrentText( m_config->device() );
  m_confWidget->comboCommand->setCurrentText( m_config->command() );
  m_confWidget->cbRingOnCall->setChecked( m_config->ringOnCall() );
  m_confWidget->cbAutoStart->setChecked( m_config->autoStart() );
  m_confWidget->cbLogAnon->setChecked( m_config->logAnonymous() );
  m_confWidget->sbEntryLimit->setValue( m_config->entryLimit() );

  m_confWidget->sbEntryLimit->setRange( 0, 1024, 1, true );

  vbox->setStretchFactor( new QWidget( vbox ), 1 );
}

KallersConfDialog::~KallersConfDialog()
{
}

void KallersConfDialog::slotOk()
{
  slotApply();
  accept();
}

void KallersConfDialog::slotApply()
{
  m_config->setDevice( m_confWidget->comboDevice->currentText() );
  m_config->setCommand( m_confWidget->comboCommand->currentText() );
  m_config->setRingOnCall( m_confWidget->cbRingOnCall->isChecked() );
  m_config->setAutoStart( m_confWidget->cbAutoStart->isChecked() );
  m_config->setLogAnon( m_confWidget->cbLogAnon->isChecked() );
  m_config->setEntryLimit( m_confWidget->sbEntryLimit->value() );

  m_config->save();

  emit configChanged();
}

#include "kallersconfdialog.moc"

/* vim: et sw=2 ts=2
*/

