/* This file is part of the KDE project
   Copyright (C) 2002-2003 Nadeem Hasan <nhasan@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or ( at your option ) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <kconfig.h>
#include <kglobal.h>

#include "kallersconfig.h"

KallersConfig::KallersConfig() : QObject( 0, "KallerConfig" )
{
  m_config = KGlobal::config();

  load();
}

KallersConfig::~KallersConfig()
{
}

KallersConfig *KallersConfig::m_instance = 0;

KallersConfig *KallersConfig::instance()
{
  if ( m_instance == 0 )
    m_instance = new KallersConfig();

  return m_instance;
}

void KallersConfig::load()
{
  m_config->setGroup( "General" );

  m_device = m_config->readEntry( "Device", "/dev/modem" );
  m_command = m_config->readEntry( "Command", "AT#CID=1" );
  m_ringOnCall = m_config->readBoolEntry( "RingOnCall", true );
  m_autoStart = m_config->readBoolEntry( "AutoStart", false );
  m_logAnon = m_config->readBoolEntry( "LogAnon", true );
  m_entryLimit = m_config->readNumEntry( "EntryLimit", 64 );
}

void KallersConfig::save()
{
  m_config->setGroup( "General" );

  m_config->writeEntry( "Device", m_device );
  m_config->writeEntry( "Command", m_command );
  m_config->writeEntry( "RingOnCall", m_ringOnCall );
  m_config->writeEntry( "AutoStart", m_autoStart );
  m_config->writeEntry( "LogAnon", m_logAnon );
  m_config->writeEntry( "EntryLimit", m_entryLimit );

  m_config->sync();
}

void KallersConfig::setDevice( QString device )
{
  if ( m_device != device )
  {
    m_device = device;
    emit modemDeviceChanged();
  }
}

#include "kallersconfig.moc"

/* vim: et sw=2 ts=2
*/

